/* @override http://localhost:8000/static/css/tree.css */

/* */

.actions a{
	border: solid thin #ccc;
	text-decoration: none;
	background: #ddd;
	font-size: 1em;
	padding: 1px 1px 1px 1px;
}

#nodes {
	width: 600px;
	margin-top: 5px;
	font-size: small;
}

li.nav-node {
	border: solid 2px #222;
	margin-top: 5px;
	padding: 4px 4px 4px 4px;
	list-style: none;
	z-index: 1;
	background: #f7f7f7;
}

.ui-autocomplete .ui-menu-item {
	font-size: 12px;
}

.ui-autocomplete-category{
	background-color: #cbd4e3;
	color: white;
	font-weight: normal;
	font-style: normal;
}

.add_object_section {
	border: thin #ccc solid;
	padding: 10px;
}

#add_object{
	top: 2px;
	position: relative;
	height: 22px;
}

#object_label{
	height: 14px;
	width: 250px;
}

aside, #aside {
	float: right;
	width: 50%;
	border: solid 2px #eee;
	min-height: 100px;
	padding: 10px 10px;
	font-size: small;
}


.button-bar {
	font-size: 10px;
	margin-bottom: 10px;
}

.content-links {
	margin: 0;
}

.content-links li{
	font-size: 12px;
	font-weight: bold;
	line-height: 16px;
}

